==> calico_3.29.1%2Bds.orig.tar.xz: calico-3.29.1/libcalico-go/lib/backend/k8s/resources/tiers.go <==
// Copyright (c) 2024 Tigera, Inc. All rights reserved.

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package resources

import (
	"fmt"
	"reflect"

	apiv3 "github.com/projectcalico/api/pkg/apis/projectcalico/v3"

	cresources "github.com/projectcalico/calico/libcalico-go/lib/resources"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/client-go/kubernetes"
	"k8s.io/client-go/rest"
)

const (
	TierResourceName = "Tiers"
	TierCRDName      = "tiers.crd.projectcalico.org"
)

func NewTierClient(c *kubernetes.Clientset, r *rest.RESTClient) K8sResourceClient {
	return &customK8sResourceClient{
		clientSet:       c,
		restClient:      r,
		name:            TierCRDName,
		resource:        TierResourceName,
		description:     "Calico Tiers",
		k8sResourceType: reflect.TypeOf(apiv3.Tier{}),
		k8sResourceTypeMeta: metav1.TypeMeta{
			Kind:       apiv3.KindTier,
			APIVersion: apiv3.GroupVersionCurrent,
		},
		k8sListType:      reflect.TypeOf(apiv3.TierList{}),
		resourceKind:     apiv3.KindTier,
		versionconverter: tierv1v3Converter{},
	}
}

// tierv1v3Converter implements VersionConverter interface.
type tierv1v3Converter struct{}

// ConvertFromK8s converts v1 Tier Resource to v3 Tier resource
func (c tierv1v3Converter) ConvertFromK8s(inRes Resource) (Resource, error) {
	tier, ok := inRes.(*apiv3.Tier)
	if !ok {
		return nil, fmt.Errorf("invalid type conversion")
	}
	cresources.DefaultTierFields(tier)
	return tier, nil
}

==> calico_3.29.3%2Bds.orig.tar.xz: calico-3.29.3/libcalico-go/lib/backend/k8s/resources/tiers.go <==
// Copyright (c) 2024 Tigera, Inc. All rights reserved.

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package resources

import (
	"fmt"
	"reflect"

	apiv3 "github.com/projectcalico/api/pkg/apis/projectcalico/v3"

	cresources "github.com/projectcalico/calico/libcalico-go/lib/resources"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/client-go/kubernetes"
	"k8s.io/client-go/rest"
)

const (
	TierResourceName = "Tiers"
	TierCRDName      = "tiers.crd.projectcalico.org"
)

func NewTierClient(c kubernetes.Interface, r rest.Interface) K8sResourceClient {
	return &customK8sResourceClient{
		clientSet:       c,
		restClient:      r,
		name:            TierCRDName,
		resource:        TierResourceName,
		description:     "Calico Tiers",
		k8sResourceType: reflect.TypeOf(apiv3.Tier{}),
		k8sResourceTypeMeta: metav1.TypeMeta{
			Kind:       apiv3.KindTier,
			APIVersion: apiv3.GroupVersionCurrent,
		},
		k8sListType:      reflect.TypeOf(apiv3.TierList{}),
		resourceKind:     apiv3.KindTier,
		versionconverter: tierv1v3Converter{},
	}
}

// tierv1v3Converter implements VersionConverter interface.
type tierv1v3Converter struct{}

// ConvertFromK8s converts v1 Tier Resource to v3 Tier resource
func (c tierv1v3Converter) ConvertFromK8s(inRes Resource) (Resource, error) {
	tier, ok := inRes.(*apiv3.Tier)
	if !ok {
		return nil, fmt.Errorf("invalid type conversion")
	}
	cresources.DefaultTierFields(tier)
	return tier, nil
}
